@@ -1,7 +1,4 @@
 from uuid import uuid4
-from maelstrom.search import Search
-from maelstrom.tests.account import Account
-from maelstrom.lookup import LookUp
 from maelstrom.data import Data
 from test import CassandraTestCase
 
@@ -18,26 +15,25 @@ class DBUnitTests(CassandraTestCase):
     def setUp(self):
         self.ids_used = []
         CassandraTestCase.setUp(self, ['127.0.0.1'], 'test')
-        #Search.rebuild()
-        #LookUp.rebuild()
-        #Data.rebuild()
+        Data.rebuild()
         #c.start(['192.241.181.163', '107.170.88.98'], 'gradfly')
-        # try:
-        #     c.start(['192.241.181.163', '107.170.88.98'], 'gradfly')
-        # except Exception:
-        #     from time import sleep
-        #     print 'failed'
-        #     sleep(50000)
-        # finally:
-        #     c.start(['192.241.181.163', '107.170.88.98'], 'gradfly')
-
+        '''
+        try:
+            c.start(['192.241.181.163', '107.170.88.98'], 'gradfly')
+        except Exception:
+            from time import sleep
+            print 'failed'
+            sleep(50000)
+        finally:
+            c.start(['192.241.181.163', '107.170.88.98'], 'gradfly')
+        '''
     def test_get_and_put_by_id(self):
         init_id = uuid4()
         self.ids_used.append(init_id)
         data = Data(id=init_id, contents="john ")
         data.commit()
         test_data = Data.get_by_id(init_id)
-        # for i,j in zip(user_1.__dict__.values(), test_user_1.__dict__.values()):
+        #for i,j in zip(user_1.__dict__.values(), test_user_1.__dict__.values()):
         #	print i,j, i == j
         self.assertEqual(data, test_data)
 
